==> cloud-5.0.0-rc1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/organisms/CloudServiceProviderTable.tsx <==
import SortInfo from 'model/SortInfo';
import LoadingSpinner from 'molecules/LoadingSpinner';
import DataTable from 'organisms/DataTable';
import { useContext, useState } from 'react';
import { Form } from 'react-bootstrap';
import { useTranslation } from 'react-i18next';
import { AppContext } from 'service/state';

/**
 * Table of cloud service providers.
 */
const CloudServiceProviderTable = () => {

  const { t } = useTranslation();
  const { cloudContextList, loadingFlg } = useContext(AppContext);
  const [sortInfo, setSortInfo] = useState<SortInfo>({
    key: '', direction: 'ASC'
  });

  return <Form>
    <Form.Group>
      <h1 className="page-header">{t('Cloud Service Providers')}</h1>
    </Form.Group>
    {
      loadingFlg
        ? <LoadingSpinner />
        : <DataTable
          dataColumnList={[{ key: 'labelName', label: 'Name' }]}
          dataRecordList={
            cloudContextList
              .sort((a, b) => {
                const keyA = a.labelName;
                const keyB = b.labelName;
                if (sortInfo.direction === 'ASC') {
                  return keyA > keyB ? 1 : -1;
                } else {
                  return keyA > keyB ? -1 : 1;
                }
              })
              .filter((r) => r.name !== 'ALL')
              .map((r) => {
                return {
                  id: `${r.cloudServiceProvider}_${r.name}`,
                  entityTypeId: '',
                  value: { 'labelName': r.labelName },
                  cloudContext: r.name
                };
              })
          }
          sortInfo={sortInfo}
          setSortInfo={setSortInfo}
          hasOperationLinks={false}
          operationLinksName="Operations"
        />
    }
  </Form>;

}

export default CloudServiceProviderTable;

==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/organisms/CloudServiceProviderTable.tsx <==
import { CLOUD_SERVICE_PROVIDER_INFO } from 'constant/others/other';
import SortInfo from 'model/SortInfo';
import LoadingSpinner from 'molecules/LoadingSpinner';
import DataTable from 'organisms/DataTable';
import { useContext, useState } from 'react';
import { Form } from 'react-bootstrap';
import { AppContext } from 'service/state';

/**
 * Table of cloud service providers.
 */
const CloudServiceProviderTable = () => {

  const { cloudContextList, loadingFlg } = useContext(AppContext);
  const [sortInfo, setSortInfo] = useState<SortInfo>({
    key: '', direction: 'ASC'
  });

  return <Form>
    <Form.Group>
      <h1 className="page-header">{Drupal.t('Cloud Service Providers')}</h1>
    </Form.Group>
    {
      loadingFlg
        ? <LoadingSpinner />
        : <DataTable
          dataColumnList={[{ key: 'labelName', label: 'Name' }]}
          dataRecordList={
            cloudContextList
              .sort((a, b) => {
                const keyA = a.labelName;
                const keyB = b.labelName;
                if (sortInfo.direction === 'ASC') {
                  return keyA > keyB ? 1 : -1;
                } else {
                  return keyA > keyB ? -1 : 1;
                }
              })
              .filter((r) => r.name !== 'ALL')
              .map((r) => {
                const temp = CLOUD_SERVICE_PROVIDER_INFO[r.cloudServiceProvider];
                return {
                  id: `${r.cloudServiceProvider}_${r.name}`,
                  entityTypeId: '',
                  value: {
                    'labelName': r.labelName,
                    'url': `/${r.cloudServiceProvider}/${r.name}/${temp.entityTypeId}`
                  },
                  cloudContext: r.name
                };
              })
          }
          sortInfo={sortInfo}
          setSortInfo={setSortInfo}
          hasOperationLinks={false}
          operationLinksName="Operations"
          detailInfo={{
            column: 'labelName',
            path: 'test'
          }}
        />
    }
  </Form>;

}

export default CloudServiceProviderTable;
